@@ -5,7 +5,6 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 #include "lookup.h"
-#include "global_objects.hpp"
 #include <QMessageBox>
 #include <QTextStream>
 #include <QDesktopServices>
@@ -41,69 +40,121 @@ void MainWindow::changeEvent(QEvent *e)
     }
 }
 
+void MainWindow::insert(QString sValue)
+{
+    /*double dCurVal = ui->dsbValues->value();
+    QString sCurVal;
+    QTextStream(&sCurVal) << dCurVal;
+    bool ok;
+
+    if (sValue != "<")
+    {
+        sCurVal.append(sValue);
+
+        double dNewVal = sCurVal.toDouble(&ok);
+        if (ok)
+        {
+            ui->dsbValues->setValue(dNewVal);
+        }
+    }
+    else
+    {
+        sCurVal = sCurVal.left(sCurVal.length()-1);
+        double dNewVal = sCurVal.toDouble(&ok);
+        if (ok)
+        {
+            ui->dsbValues->setValue(dNewVal);
+        }
+        else
+        {
+            ui->dsbValues->setValue(0);
+        }
+    }*/
+}
+
 
 void MainWindow::on_pushButton_1_clicked()
 {
    ui->lineEdit->insert("1");
+   //insert("1");
 }
 
 void MainWindow::on_pushButton_2_clicked()
 {
+    //insert("2");
     ui->lineEdit->insert("2");
 }
 
 void MainWindow::on_pushButton_3_clicked()
 {
+//    insert("3");
+
     ui->lineEdit->insert("3");
 }
 
 void MainWindow::on_pushButton_4_clicked()
 {
+    //insert("4");
+
     ui->lineEdit->insert("4");
 }
 
 void MainWindow::on_pushButton_5_clicked()
 {
+    //insert("5");
+
     ui->lineEdit->insert("5");
 }
 
 void MainWindow::on_pushButton_6_clicked()
 {
+    //insert("6");
     ui->lineEdit->insert("6");
 }
 
 void MainWindow::on_pushButton_7_clicked()
 {
+    //insert("7");
     ui->lineEdit->insert("7");
 }
 
 void MainWindow::on_pushButton_8_clicked()
 {
+//    insert("8");
     ui->lineEdit->insert("8");
 }
 
 void MainWindow::on_pushButton_9_clicked()
 {
     ui->lineEdit->insert("9");
+  //  insert("9");
+
 }
 
 void MainWindow::on_pushButton_0_clicked()
 {
     ui->lineEdit->insert("0");
+//    insert("0");
+
 }
 
 void MainWindow::on_pushButton_Dot_clicked()
 {
+  //  insert(".");
+
     ui->lineEdit->insert(".");
 }
 
 void MainWindow::on_pushButton_Del_clicked()
 {
+  //  insert("<");
+
     ui->lineEdit->backspace();
 }
 
 void MainWindow::on_pushButton_Clear_clicked()
 {
+//    ui->dsbValues->setValue(0);
     ui->lineEdit->clear();
     ui->lineEdit->setText("");
     ui->label_Main->setText("Calories:");
@@ -1476,10 +1527,11 @@ double MainWindow::getPoints()
 
 void MainWindow::on_pushButton_Go_clicked()
 {
+    //double dValue = ui->dsbValues->value();
     QString sss = ui->lineEdit->text();
     if (sss.length() == 0 )
     {
-        ui->label_Answer->setText("Please enter a valid number");
+        ui->label_Answer->setText("Enter a valid no.");
         return;
     }
 
@@ -1489,6 +1541,7 @@ void MainWindow::on_pushButton_Go_clicked()
         ui->pushButton_Go->setText("Calculate");
         ui->label_Main->setText("Saturated Fat:");
         mdCals = ui->lineEdit->text().toDouble();
+//        ui->dsbValues->setValue(0);
         ui->lineEdit->setText("");
     }
     else
@@ -1602,3 +1655,80 @@ void MainWindow::on_btnDonate_clicked()
     url.setUrl("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=J7AH48HQ5F738");
     QDesktopServices::openUrl(url);
 }
+
+void MainWindow::on_lineEdit_textChanged(QString )
+{
+    QString qNewValue = ui->lineEdit->text();
+    bool ok;
+    double dTest = qNewValue.toDouble(&ok);
+    int dotCnt=0;
+    if (!ok)
+    {
+        QString qStripped;
+
+        for (int i=0; i< qNewValue.length(); i++ )
+        {
+            QString subStr = qNewValue.at(i);
+            QString sValid = "1234567890.";
+            if (subStr.toLower() == ":")
+            {
+                subStr = ".";
+            }
+            if (subStr.toLower() == "?")
+            {
+                subStr = ".";
+            }
+
+            if (subStr==".")
+            {
+                dotCnt++;
+            }
+            if (subStr.toLower() == "q")
+            {
+                subStr = "1";
+            }
+            if (subStr.toLower() == "w")
+            {
+                subStr = "2";
+            }
+            if (subStr.toLower() == "e")
+            {
+                subStr = "3";
+            }
+            if (subStr.toLower() == "r")
+            {
+                subStr = "4";
+            }
+            if (subStr.toLower() == "t")
+            {
+                subStr = "5";
+            }
+            if (subStr.toLower() == "y")
+            {
+                subStr = "6";
+            }
+            if (subStr.toLower() == "u")
+            {
+                subStr = "7";
+            }
+            if (subStr.toLower() == "i")
+            {
+                subStr = "8";
+            }
+            if (subStr.toLower() == "o")
+            {
+                subStr = "9";
+            }
+            if (subStr.toLower() == "p")
+            {
+                subStr = "0";
+            }
+            if ( (sValid.contains( subStr)) && (dotCnt <= 1))
+            {
+                qStripped.append(subStr);
+            }
+        }
+        ui->lineEdit->setText(qStripped);
+    }
+
+}
