@@ -16,16 +16,20 @@ public:
     void setMode(QString sNewMode);
     void setPoints(QString sNewPts);
     void setDisableName();
+    void setEnableName();
 
 protected:
     void changeEvent(QEvent *e);
     QString sMode;
+    QString getExistingUDFLine(QString sCompLine);
 
 private:
     Ui::StoreFood *ui;
     QSettings mSelFood;
 
 private slots:
+    void on_btnHelp_clicked();
+    void on_txtCost_textChanged(QString );
     void on_btnClose_clicked();
     void on_btnCancel_clicked();
     void on_btnNew_clicked();
